EXPORTS
	?PlaceholderForRemovedExport1@CMDXMLComposer@@AAEXPAVMMDXMLComposerObserver@@@Z @ 1 NONAME ; private: void __thiscall CMDXMLComposer::PlaceholderForRemovedExport1(class MMDXMLComposerObserver *)
	??0CMDXMLEntityConverter@@QAE@XZ @ 2 NONAME ; public: __thiscall CMDXMLEntityConverter::CMDXMLEntityConverter(void)
	?PlaceholderForRemovedExport1@CMDXMLParser@@AAEXPAVMMDXMLParserObserver@@@Z @ 3 NONAME ; private: void __thiscall CMDXMLParser::PlaceholderForRemovedExport1(class MMDXMLParserObserver *)
	?PlaceholderForRemovedExport2@CMDXMLParser@@AAEXPAVMMDXMLParserObserver@@PAVMXMLDtd@@@Z @ 4 NONAME ; private: void __thiscall CMDXMLParser::PlaceholderForRemovedExport2(class MMDXMLParserObserver *,class MXMLDtd *)
	??1CMDXMLComposer@@UAE@XZ @ 5 NONAME ; public: virtual __thiscall CMDXMLComposer::~CMDXMLComposer(void)
	??1CMDXMLEntityConverter@@UAE@XZ @ 6 NONAME ; public: virtual __thiscall CMDXMLEntityConverter::~CMDXMLEntityConverter(void)
	??1CMDXMLParser@@UAE@XZ @ 7 NONAME ; public: virtual __thiscall CMDXMLParser::~CMDXMLParser(void)
	?PlaceholderForRemovedExport2@CMDXMLComposer@@AAEXXZ @ 8 NONAME ; private: void __thiscall CMDXMLComposer::PlaceholderForRemovedExport2(void)
	?ComposeEndTagL@CMDXMLComposer@@AAEHAAVCMDXMLNode@@@Z @ 9 NONAME ; private: int __thiscall CMDXMLComposer::ComposeEndTagL(class CMDXMLNode &)
	?ComposeFile@CMDXMLComposer@@QAEHVRFs@@ABVTDesC16@@PAVCMDXMLDocument@@W4TXMLFileType@@@Z @ 10 NONAME ; public: int __thiscall CMDXMLComposer::ComposeFile(class RFs,class TDesC16 const &,class CMDXMLDocument *,enum TXMLFileType)
	?ComposeStartTagL@CMDXMLComposer@@AAEHAAVCMDXMLNode@@@Z @ 11 NONAME ; private: int __thiscall CMDXMLComposer::ComposeStartTagL(class CMDXMLNode &)
	?DetachXMLDoc@CMDXMLParser@@QAEPAVCMDXMLDocument@@XZ @ 12 NONAME ; public: class CMDXMLDocument * __thiscall CMDXMLParser::DetachXMLDoc(void)
	?DoCancel@CMDXMLComposer@@EAEXXZ @ 13 NONAME ; private: virtual void __thiscall CMDXMLComposer::DoCancel(void)
	?DoCancel@CMDXMLParser@@EAEXXZ @ 14 NONAME ; private: virtual void __thiscall CMDXMLParser::DoCancel(void)
	?E32Dll@@YAHW4TDllReason@@@Z @ 15 NONAME ABSENT ; int __cdecl E32Dll(enum TDllReason)
	?NewL@CMDXMLComposer@@SAPAV1@PAVMMDXMLComposerObserver@@@Z @ 16 NONAME ; public: static class CMDXMLComposer * __cdecl CMDXMLComposer::NewL(class MMDXMLComposerObserver *)
	?NewL@CMDXMLParser@@SAPAV1@PAVMMDXMLParserObserver@@@Z @ 17 NONAME ; public: static class CMDXMLParser * __cdecl CMDXMLParser::NewL(class MMDXMLParserObserver *)
	?NewL@CMDXMLParser@@SAPAV1@PAVMMDXMLParserObserver@@PAVMXMLDtd@@@Z @ 18 NONAME ; public: static class CMDXMLParser * __cdecl CMDXMLParser::NewL(class MMDXMLParserObserver *,class MXMLDtd *)
	?NewLC@CMDXMLComposer@@SAPAV1@PAVMMDXMLComposerObserver@@@Z @ 19 NONAME ; public: static class CMDXMLComposer * __cdecl CMDXMLComposer::NewLC(class MMDXMLComposerObserver *)
	?NewLC@CMDXMLParser@@SAPAV1@PAVMMDXMLParserObserver@@@Z @ 20 NONAME ; public: static class CMDXMLParser * __cdecl CMDXMLParser::NewLC(class MMDXMLParserObserver *)
	?NewLC@CMDXMLParser@@SAPAV1@PAVMMDXMLParserObserver@@PAVMXMLDtd@@@Z @ 21 NONAME ; public: static class CMDXMLParser * __cdecl CMDXMLParser::NewLC(class MMDXMLParserObserver *,class MXMLDtd *)
	?OutputAttributeL@CMDXMLComposer@@QAEHABVTDesC16@@0@Z @ 22 NONAME ; public: int __thiscall CMDXMLComposer::OutputAttributeL(class TDesC16 const &,class TDesC16 const &)
	?OutputComposedTextL@CMDXMLEntityConverter@@UAEHPAVCMDXMLComposer@@ABVTDesC16@@@Z @ 23 NONAME ; public: virtual int __thiscall CMDXMLEntityConverter::OutputComposedTextL(class CMDXMLComposer *,class TDesC16 const &)
	?OutputEndOfElementTagL@CMDXMLComposer@@QAEHH@Z @ 24 NONAME ; public: int __thiscall CMDXMLComposer::OutputEndOfElementTagL(int)
	?OutputStartOfElementTagL@CMDXMLComposer@@QAEHABVTDesC16@@@Z @ 25 NONAME ; public: int __thiscall CMDXMLComposer::OutputStartOfElementTagL(class TDesC16 const &)
	?ParseFile@CMDXMLParser@@QAEHVRFs@@ABVTDesC16@@@Z @ 26 NONAME ; public: int __thiscall CMDXMLParser::ParseFile(class RFs,class TDesC16 const &)
	?RunError@CMDXMLComposer@@EAEHH@Z @ 27 NONAME ; private: virtual int __thiscall CMDXMLComposer::RunError(int)
	?RunError@CMDXMLParser@@EAEHH@Z @ 28 NONAME ; private: virtual int __thiscall CMDXMLParser::RunError(int)
	?PlaceholderForRemovedExport3@CMDXMLComposer@@AAEXXZ @ 29 NONAME ; private: void __thiscall CMDXMLComposer::PlaceholderForRemovedExport3(void)
	?PlaceholderForRemovedExport3@CMDXMLParser@@AAEXXZ @ 30 NONAME ; private: void __thiscall CMDXMLParser::PlaceholderForRemovedExport3(void)
	?SetError@CMDXMLComposer@@AAEXHW4TXMLErrorCodeSeverity@@@Z @ 31 NONAME ; private: void __thiscall CMDXMLComposer::SetError(int,enum TXMLErrorCodeSeverity)
	?SetError@CMDXMLParser@@AAEXHW4TXMLErrorCodeSeverity@@@Z @ 32 NONAME ; private: void __thiscall CMDXMLParser::SetError(int,enum TXMLErrorCodeSeverity)
	?Error@CMDXMLComposer@@QBEHXZ @ 33 NONAME ; int CMDXMLComposer::Error(void) const
	?Error@CMDXMLParser@@QBEHXZ @ 34 NONAME ; int CMDXMLParser::Error(void) const
	?EntityConverter@CMDXMLComposer@@QBEPAVCMDXMLEntityConverter@@XZ @ 35 NONAME ; public: class CMDXMLEntityConverter * __thiscall CMDXMLComposer::EntityConverter(void)const 
	?NewL@CMDXMLComposer@@SAPAV1@PAVMMDXMLComposerObserver@@H@Z @ 36 NONAME ; public: static class CMDXMLComposer * __cdecl CMDXMLComposer::NewL(class MMDXMLComposerObserver *,int)
	?NewLC@CMDXMLComposer@@SAPAV1@PAVMMDXMLComposerObserver@@H@Z @ 37 NONAME ; public: static class CMDXMLComposer * __cdecl CMDXMLComposer::NewLC(class MMDXMLComposerObserver *,int)
	?CalculateFileSize@CMDXMLComposer@@QAEHAAHPAVCMDXMLDocument@@W4TXMLFileType@@@Z @ 38 NONAME ; public: int __thiscall CMDXMLComposer::CalculateFileSize(int &,class CMDXMLDocument *,enum TXMLFileType)
	?OutputDataL@CMDXMLComposer@@QAEHABVTDesC16@@@Z @ 39 NONAME ; public: int __thiscall CMDXMLComposer::OutputDataL(class TDesC16 const &)
	?SetEntityConverter@CMDXMLComposer@@QAEXPAVCMDXMLEntityConverter@@@Z @ 40 NONAME ; public: void __thiscall CMDXMLComposer::SetEntityConverter(class CMDXMLEntityConverter *)
	?SetEntityConverter@CMDXMLParser@@QAEXPAVCMDXMLEntityConverter@@@Z @ 41 NONAME ; public: void __thiscall CMDXMLParser::SetEntityConverter(class CMDXMLEntityConverter *)
	?ErrorSeverity@CMDXMLComposer@@QBE?AW4TXMLErrorCodeSeverity@@XZ @ 42 NONAME ; public: enum TXMLErrorCodeSeverity  __thiscall CMDXMLComposer::ErrorSeverity(void)const 
	?ErrorSeverity@CMDXMLParser@@QBE?AW4TXMLErrorCodeSeverity@@XZ @ 43 NONAME ; public: enum TXMLErrorCodeSeverity  __thiscall CMDXMLParser::ErrorSeverity(void)const
	?ParseSource@CMDXMLParser@@QAEXPAVMMDXMLParserDataProvider@@@Z @ 44 NONAME ; public: void __thiscall CMDXMLParser::ParseSource(class MMDXMLParserDataProvider *)
	?SetSourceCharacterWidth@CMDXMLParser@@QAEXW4TMDXMLParserInputCharWidth@1@@Z @ 45 NONAME ; public: void __thiscall CMDXMLParser::SetSourceCharacterWidth(enum CMDXMLParser::TMDXMLParserInputCharWidth)
	?SetStoreInvalid@CMDXMLParser@@QAEXH@Z @ 46 NONAME ; void CMDXMLParser::SetStoreInvalid(int)

